<?php
/**
 * spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Zigor Astarbe <zigor@astarbe.com>
 * @author Adrián Ariza <adrian_ariza.ciudad.com.ar>
 * @author Gabiel Molina <gabriel191@gmail.com>
 * @author Paco Avila <monkiki@gmail.com>
 * @author Bernardo Arlandis Mañó <bernardo@tsolucio.com>
 * @author Miguel Pagano <miguel.pagano@gmail.com>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Manuel Meco <manuel.meco@gmail.com>
 * @author Jordan Mero <hack.jord@gmail.com>
 * @author Felipe Martinez <metalmartinez@gmail.com>
 * @author Javier Aranda <internet@javierav.com>
 * @author Zerial <fernando@zerial.org>
 * @author Marvin Ortega <maty1206@maryanlinux.com>
 * @author Daniel Castro Alvarado <dancas2@gmail.com>
 * @author Fernando J. Gómez <fjgomez@gmail.com>
 * @author Victor Castelan <victorcastelan@gmail.com>
 * @author Mauro Javier Giamberardino <mgiamberardino@gmail.com>
 * @author emezeta <emezeta@infoprimo.com>
 * @author Oscar Ciudad <oscar@jacho.net>
 * @author Ruben Figols <ruben.figols@gmail.com>
 * @author Gerardo Zamudio <gerardo@gerardozamudio.net>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Editar esta página';
$lang['btn_source']            = 'Ver fuente';
$lang['btn_show']              = 'Ver página';
$lang['btn_create']            = 'Crear esta página';
$lang['btn_search']            = 'Buscar';
$lang['btn_save']              = 'Guardar';
$lang['btn_preview']           = 'Previsualización';
$lang['btn_top']               = 'Ir hasta arriba';
$lang['btn_newer']             = '<< más reciente';
$lang['btn_older']             = 'menos reciente >>';
$lang['btn_revs']              = 'Revisiones antiguas';
$lang['btn_recent']            = 'Cambios recientes';
$lang['btn_upload']            = 'Cargar';
$lang['btn_cancel']            = 'Cancelar';
$lang['btn_index']             = 'Índice';
$lang['btn_secedit']           = 'Editar';
$lang['btn_login']             = 'Conectarse';
$lang['btn_logout']            = 'Desconectarse';
$lang['btn_admin']             = 'Administrar';
$lang['btn_update']            = 'Actualizar';
$lang['btn_delete']            = 'Borrar';
$lang['btn_back']              = 'Atrás';
$lang['btn_backlink']          = 'Enlaces a esta página';
$lang['btn_backtomedia']       = 'Volver a la selección de archivos multimedia';
$lang['btn_subscribe']         = 'Suscribirse a cambios de la página';
$lang['btn_profile']           = 'Actualizar perfil';
$lang['btn_reset']             = 'Restablecer';
$lang['btn_resendpwd']         = 'Establecer nueva contraseña';
$lang['btn_draft']             = 'Editar borrador';
$lang['btn_recover']           = 'Recuperar borrador';
$lang['btn_draftdel']          = 'Eliminar borrador';
$lang['btn_revert']            = 'Restaurar';
$lang['btn_register']          = 'Registrarse';
$lang['btn_apply']             = 'Aplicar';
$lang['btn_media']             = 'Gestor de ficheros';
$lang['loggedinas']            = 'Conectado como ';
$lang['user']                  = 'Usuario';
$lang['pass']                  = 'Contraseña';
$lang['newpass']               = 'Nueva contraseña';
$lang['oldpass']               = 'Confirma tu contraseña actual';
$lang['passchk']               = 'otra vez';
$lang['remember']              = 'Recordarme';
$lang['fullname']              = 'Nombre real';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Perfil del usuario';
$lang['badlogin']              = 'Lo siento, el usuario o la contraseña es incorrecto.';
$lang['minoredit']             = 'Cambios menores';
$lang['draftdate']             = 'Borrador guardado automáticamente:';
$lang['nosecedit']             = 'La página ha cambiado en el lapso, la información de sección estaba anticuada, en su lugar se cargó la página completa.';
$lang['regmissing']            = 'Lo siento, tienes que completar todos los campos.';
$lang['reguexists']            = 'Lo siento, ya existe un usuario con este nombre.';
$lang['regsuccess']            = 'El usuario ha sido creado y la contraseña se ha enviado por correo.';
$lang['regsuccess2']           = 'El usuario ha sido creado.';
$lang['regmailfail']           = 'Parece que ha habido un error al enviar el correo con la contraseña. ¡Por favor, contacta al administrador!';
$lang['regbadmail']            = 'La dirección de correo no parece válida. Si piensas que esto es un error, contacta al administrador';
$lang['regbadpass']            = 'Las dos contraseñas no son iguales, por favor inténtalo de nuevo.';
$lang['regpwmail']             = 'Tu contraseña de DokuWiki';
$lang['reghere']               = '¿No tienes una cuenta todavía? Consigue una';
$lang['profna']                = 'Este wiki no permite la modificación del perfil';
$lang['profnochange']          = 'Sin cambios, nada que hacer.';
$lang['profnoempty']           = 'No se permite que el nombre o la dirección de correo electrónico estén vacíos.';
$lang['profchanged']           = 'Se actualizó correctamente el perfil del usuario.';
$lang['pwdforget']             = '¿Has olvidado tu contraseña? Consigue una nueva';
$lang['resendna']              = 'Este wiki no brinda la posibilidad de reenvío de contraseña.';
$lang['resendpwd']             = 'Establecer nueva contraseña para';
$lang['resendpwdmissing']      = 'Lo siento, debes completar todos los campos.';
$lang['resendpwdnouser']       = 'Lo siento, no se encuentra este usuario en nuestra base de datos.';
$lang['resendpwdbadauth']      = 'Lo siento, este código de autenticación no es válido. Asegúrate de haber usado el enlace de confirmación entero.';
$lang['resendpwdconfirm']      = 'Un enlace para confirmación ha sido enviado por correo electrónico.';
$lang['resendpwdsuccess']      = 'Tu nueva contraseña ha sido enviada por correo electrónico.';
$lang['license']               = 'Excepto donde se indique lo contrario, el contenido de esta wiki se autoriza bajo la siguiente licencia:';
$lang['licenseok']             = 'Nota: Al editar esta página, estás de acuerdo en autorizar su contenido bajo la siguiente licencia:';
$lang['searchmedia']           = 'Buscar archivo:';
$lang['searchmedia_in']        = 'Buscar en %s';
$lang['txt_upload']            = 'Selecciona el archivo a subir';
$lang['txt_filename']          = 'Subir como (opcional)';
$lang['txt_overwrt']           = 'Sobreescribir archivo existente';
$lang['maxuploadsize']         = 'Peso máximo de %s por archivo';
$lang['lockedby']              = 'Actualmente bloqueado por';
$lang['lockexpire']            = 'El bloqueo expira en';
$lang['js']['willexpire']      = 'El bloqueo para la edición de esta página expira en un minuto.\nPAra prevenir conflictos uso el botón Previsualizar para restaurar el contador de bloqueo.';
$lang['js']['notsavedyet']     = 'Los cambios que no se han guardado se perderán.
¿Realmente quieres continuar?';
$lang['js']['searchmedia']     = 'Buscar archivos';
$lang['js']['keepopen']        = 'Mantener la ventana abierta luego de seleccionar';
$lang['js']['hidedetails']     = 'Ocultar detalles';
$lang['js']['mediatitle']      = 'Configuración del vínculo';
$lang['js']['mediadisplay']    = 'Tipo de vínculo';
$lang['js']['mediaalign']      = 'Alineación';
$lang['js']['mediasize']       = 'Tamaño de la imagen';
$lang['js']['mediatarget']     = 'Destino del vínculo';
$lang['js']['mediaclose']      = 'Cerrar';
$lang['js']['mediainsert']     = 'Insertar';
$lang['js']['mediadisplayimg'] = 'Mostrar la imagen.';
$lang['js']['mediadisplaylnk'] = 'Mostrar solo el vínculo.';
$lang['js']['mediasmall']      = 'Versión en tamaño pequeño';
$lang['js']['mediamedium']     = 'Versión en tamaño medio';
$lang['js']['medialarge']      = 'Versión en tamaño grande';
$lang['js']['mediaoriginal']   = 'Versión original';
$lang['js']['medialnk']        = 'Vínculo a la pagina de descripción';
$lang['js']['mediadirect']     = 'Vínculo al original';
$lang['js']['medianolnk']      = 'Sin vínculo';
$lang['js']['medianolink']     = 'No vincular la imagen';
$lang['js']['medialeft']       = 'Alinear imagen a la izquierda';
$lang['js']['mediaright']      = 'Alinear imagen a la derecha.';
$lang['js']['mediacenter']     = 'Alinear imagen en el centro.';
$lang['js']['medianoalign']    = 'No use alineación.';
$lang['js']['nosmblinks']      = 'El enlace a recursos compartidos de Windows sólo funciona en Microsoft Internet Explorer.
Lo que sí puedes hacer es copiar y pegar el enlace.';
$lang['js']['linkwiz']         = 'Asistente de enlaces';
$lang['js']['linkto']          = 'Enlazar a:';
$lang['js']['del_confirm']     = '¿Quieres realmente borrar lo seleccionado?';
$lang['js']['restore_confirm'] = '¿Estás seguro de querer restaurar esta versión?';
$lang['js']['media_diff']      = 'Ver diferencias:';
$lang['js']['media_diff_both'] = 'Lado por lado';
$lang['js']['media_diff_opacity'] = 'A través de Shine';
$lang['js']['media_diff_portions'] = 'Pasar';
$lang['js']['media_select']    = 'Seleccionar ficheros';
$lang['js']['media_upload_btn'] = 'Cargar';
$lang['js']['media_done_btn']  = 'Hecho';
$lang['js']['media_drop']      = 'Arrastra los ficheros aquí para cargar';
$lang['js']['media_cancel']    = 'Eliminar';
$lang['js']['media_overwrt']   = 'Sobreescribir ficheros exitentes';
$lang['rssfailed']             = 'Se ha producido un error mientras se leían los datos de este feed: ';
$lang['nothingfound']          = 'No se ha encontrado nada.';
$lang['mediaselect']           = 'Archivos Multimedia';
$lang['fileupload']            = 'Subida de archivos multimedia';
$lang['uploadsucc']            = 'El archivo se ha subido satisfactoriamente';
$lang['uploadfail']            = 'La subida del fichero ha fallado. ¿Permisos equivocados?';
$lang['uploadwrong']           = 'Subida de fichero denegada. ¡Los ficheros con esta extensión están prohibidos!';
$lang['uploadexist']           = 'El fichero ya existe. No se ha hecho nada.';
$lang['uploadbadcontent']      = 'El contenido de la subida no coincide con la extensión de fichero %s';
$lang['uploadspam']            = 'La subida ha sido bloqueada por una lista negra de spam';
$lang['uploadxss']             = 'La subida ha sido bloqueada por contenido posiblemente malicioso';
$lang['uploadsize']            = 'El fichero subido es demasiado grande. (max. %s)';
$lang['deletesucc']            = 'El fichero "%s" ha sido borrado.';
$lang['deletefail']            = '"%s" no pudo ser borrado; verifique los permisos.';
$lang['mediainuse']            = 'El fichero "%s" no ha sido borrado, aún está en uso.';
$lang['namespaces']            = 'Espacios de nombres';
$lang['mediafiles']            = 'Ficheros disponibles en';
$lang['accessdenied']          = 'No tiene permisos para ver esta página.';
$lang['mediausage']            = 'Use la siguiente sintaxis para hacer referencia a este fichero:';
$lang['mediaview']             = 'Ver el fichero original';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Subir aquí un fichero al espacio de nombres actual. Para crear sub-espacios de nombres, antepóngalos al nombre de fichero separándolos por dos puntos (:) en "Subir como".';
$lang['mediaextchange']        = 'Extensión del fichero cambiada de .%s a .%s!';
$lang['reference']             = 'Referencias para';
$lang['ref_inuse']             = 'El fichero no puede ser borrado, porque todavía se está usando en las siguientes páginas:';
$lang['ref_hidden']            = 'Algunas referencias están en páginas sobre las que no tienes permiso de lectura';
$lang['hits']                  = 'Entradas';
$lang['quickhits']             = 'Páginas que coinciden';
$lang['toc']                   = 'Tabla de Contenidos';
$lang['current']               = 'actual';
$lang['yours']                 = 'Tu versión';
$lang['diff']                  = 'Muestra diferencias a la versión actual';
$lang['diff2']                 = 'Muestra las diferencias entre las revisiones seleccionadas';
$lang['difflink']              = 'Enlace a la vista de comparación';
$lang['diff_type']             = 'Ver diferencias';
$lang['diff_inline']           = 'En línea';
$lang['diff_side']             = 'Lado a lado';
$lang['line']                  = 'Línea';
$lang['breadcrumb']            = 'Traza';
$lang['youarehere']            = 'Estás aquí';
$lang['lastmod']               = 'Última modificación';
$lang['by']                    = 'por';
$lang['deleted']               = 'borrado';
$lang['created']               = 'creado';
$lang['restored']              = 'se ha restaurado la vieja versión';
$lang['external_edit']         = 'editor externo';
$lang['summary']               = 'Resumen de la edición';
$lang['noflash']               = 'Para mostrar este contenido es necesario el <a href="http://www.adobe.com/products/flashplayer/">Plugin Adobe Flash</a>.';
$lang['download']              = 'Descargar trozo de código fuente';
$lang['tools']                 = 'Herramientas';
$lang['user_tools']            = 'Herramientas de usuario';
$lang['site_tools']            = 'Herramientas del sitio';
$lang['page_tools']            = 'Herramientas de la página';
$lang['skip_to_content']       = 'Saltar a contenido';
$lang['sidebar']               = 'Barra lateral';
$lang['mail_newpage']          = 'página añadida:';
$lang['mail_changed']          = 'página cambiada:';
$lang['mail_subscribe_list']   = 'páginas cambiadas en el espacio de nombre:';
$lang['mail_new_user']         = 'nuevo usuario:';
$lang['mail_upload']           = 'archivo subido:';
$lang['changes_type']          = 'Ver cambios de';
$lang['pages_changes']         = 'Páginas';
$lang['media_changes']         = 'Archivos multimedia';
$lang['both_changes']          = 'Ambas páginas y archivos multimedia';
$lang['qb_bold']               = 'Negrita';
$lang['qb_italic']             = 'Itálica';
$lang['qb_underl']             = 'Subrayado';
$lang['qb_code']               = 'Código';
$lang['qb_strike']             = 'Tachado';
$lang['qb_h1']                 = 'Título 1';
$lang['qb_h2']                 = 'Título 2';
$lang['qb_h3']                 = 'Título 3';
$lang['qb_h4']                 = 'Título 4';
$lang['qb_h5']                 = 'Título 5';
$lang['qb_h']                  = 'Título';
$lang['qb_hs']                 = 'Selecciona el título';
$lang['qb_hplus']              = 'Título alto';
$lang['qb_hminus']             = 'Título bajo';
$lang['qb_hequal']             = 'Título del mismo nivel';
$lang['qb_link']               = 'Enlace interno';
$lang['qb_extlink']            = 'Enlace externo';
$lang['qb_hr']                 = 'Línea horizontal';
$lang['qb_ol']                 = 'Ítem de lista ordenada';
$lang['qb_ul']                 = 'Ítem de lista desordenada';
$lang['qb_media']              = 'Añadir Imágenes u otros ficheros';
$lang['qb_sig']                = 'Insertar firma';
$lang['qb_smileys']            = 'Sonrisas';
$lang['qb_chars']              = 'Caracteres especiales';
$lang['upperns']               = 'Saltar al espacio de nombres superior';
$lang['admin_register']        = 'Añadir nuevo usuario';
$lang['metaedit']              = 'Editar metadatos';
$lang['metasaveerr']           = 'La escritura de los metadatos ha fallado';
$lang['metasaveok']            = 'Los metadatos han sido guardados';
$lang['img_backto']            = 'Volver a';
$lang['img_title']             = 'Título';
$lang['img_caption']           = 'Epígrafe';
$lang['img_date']              = 'Fecha';
$lang['img_fname']             = 'Nombre de fichero';
$lang['img_fsize']             = 'Tamaño';
$lang['img_artist']            = 'Fotógrafo';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Formato';
$lang['img_camera']            = 'Cámara';
$lang['img_keywords']          = 'Palabras claves';
$lang['img_width']             = 'Ancho';
$lang['img_height']            = 'Alto';
$lang['img_manager']           = 'Ver en el Administrador de medios';
$lang['subscr_subscribe_success'] = 'Se agregó %s a las listas de suscripción para %s';
$lang['subscr_subscribe_error'] = 'Error al agregar %s a las listas de suscripción para %s';
$lang['subscr_subscribe_noaddress'] = 'No hay dirección asociada con tu registro, no se puede agregarte a la lista de suscripción';
$lang['subscr_unsubscribe_success'] = 'Removido %s de la lista de suscripción para %s';
$lang['subscr_unsubscribe_error'] = 'Error al remover %s de la lista de suscripción para %s';
$lang['subscr_already_subscribed'] = '%s ya está suscrito a %s';
$lang['subscr_not_subscribed'] = '%s no está suscrito a %s';
$lang['subscr_m_not_subscribed'] = 'Actualmente no te encuentras suscrito a esta página o espacio de nombres';
$lang['subscr_m_new_header']   = 'Agregar suscripción';
$lang['subscr_m_current_header'] = 'Suscripciones actuales';
$lang['subscr_m_unsubscribe']  = 'Darse de baja';
$lang['subscr_m_subscribe']    = 'Suscribirse';
$lang['subscr_m_receive']      = 'Recibir';
$lang['subscr_style_every']    = 'enviar correo en cada cambio';
$lang['subscr_style_digest']   = 'recopilar correo de cambios por cada página';
$lang['subscr_style_list']     = 'lista de páginas con cambios desde el último correo';
$lang['authmodfailed']         = 'Está mal configurada la autenticación de usuarios. Por favor, avisa al administrador del wiki.';
$lang['authtempfail']          = 'La autenticación de usuarios no está disponible temporalmente. Si esta situación persiste, por favor avisa al administrador del wiki.';
$lang['authpwdexpire']         = 'Su contraseña caducara en %d días, debería cambiarla lo antes posible';
$lang['i_chooselang']          = 'Elija su idioma';
$lang['i_installer']           = 'Instalador de DokuWiki';
$lang['i_wikiname']            = 'Nombre del wiki';
$lang['i_enableacl']           = 'Habilitar ACL (recomendado) (ACL: lista de control de acceso)';
$lang['i_superuser']           = 'Super-usuario';
$lang['i_problems']            = 'El instalador encontró algunos problemas, se muestran abajo. No se puede continuar la instalación hasta que usted no los corrija.';
$lang['i_modified']            = 'Por razones de seguridad este script sólo funcionará con una instalación nueva y no modificada de Dokuwiki. Usted debe extraer nuevamente los ficheros del paquete bajado, o bien consultar las <a href="http://dokuwiki.org/install">instrucciones de instalación de Dokuwiki</a> completas.';
$lang['i_funcna']              = 'La función de PHP <code>%s</code> no está disponible. ¿Tal vez su proveedor de hosting la ha deshabilitado por alguna razón?';
$lang['i_phpver']              = 'Su versión de PHP <code>%s</code> es menor que la necesaria <code>%s</code>. Es necesario que actualice su instalación de PHP.';
$lang['i_permfail']            = 'DokuWili no puede escribir <code>%s</code>. ¡Es necesario establecer  correctamente los permisos de este directorio!';
$lang['i_confexists']          = '<code>%s</code> ya existe';
$lang['i_writeerr']            = 'Imposible crear <code>%s</code>. Se necesita que usted controle los permisos del fichero/directorio y que cree el fichero manualmente.';
$lang['i_badhash']             = 'dokuwiki.php no reconocido o modificado (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valor ilegal o vacío';
$lang['i_success']             = 'La configuración ha concluido correctamente. Ahora puede eliminar el archivo install.php. Visite <a href="doku.php">su nuevo DokuWiki</a>.';
$lang['i_failure']             = 'Han ocurrido algunos errores durante la escritura de los ficheros de configuración. Puede ser que necesite corregirlos manualmente antes de poder usar <a href="doku.php">su nuevo DokuWiki</a>.';
$lang['i_policy']              = 'Política de ACL inicial';
$lang['i_pol0']                = 'Wiki abierto (leer, escribir y subir archivos para todos)';
$lang['i_pol1']                = 'Wiki público (leer para todos, escribir y subir archivos para usuarios registrados únicamente)';
$lang['i_pol2']                = 'Wiki cerrado (leer, escribir y subir archivos para usuarios registrados únicamente)';
$lang['i_retry']               = 'Reintentar';
$lang['i_license']             = 'Por favor escoja una licencia bajo la que publicar su contenido:';
$lang['recent_global']         = 'Actualmente estás viendo los cambios dentro del namespace <b>%s</b>. También puedes <a href="%s">ver los cambios recientes en el wiki completo</a>.';
$lang['years']                 = '%d años atrás';
$lang['months']                = '%d meses atrás';
$lang['weeks']                 = '%d semanas atrás';
$lang['days']                  = '%d días atrás';
$lang['hours']                 = '%d horas atrás';
$lang['minutes']               = '%d minutos atrás';
$lang['seconds']               = '%d segundos atrás';
$lang['wordblock']             = 'Sus cambios no se han guardado porque contienen textos bloqueados (spam).';
$lang['media_uploadtab']       = 'Cargar';
$lang['media_searchtab']       = 'Buscar';
$lang['media_file']            = 'Fichero';
$lang['media_viewtab']         = 'Ver';
$lang['media_edittab']         = 'Editar';
$lang['media_historytab']      = 'Historial';
$lang['media_list_thumbs']     = 'Miniaturas';
$lang['media_list_rows']       = 'Celdas';
$lang['media_sort_name']       = 'Nombre';
$lang['media_sort_date']       = 'Fecha';
$lang['media_namespaces']      = 'Escoge "espacio de nombre"';
$lang['media_files']           = 'Ficheros en %s';
$lang['media_upload']          = 'Cargar a %s';
$lang['media_search']          = 'Buscar en %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s en %s';
$lang['media_edit']            = 'Editar %s';
$lang['media_history']         = 'Historial de %s';
$lang['media_meta_edited']     = 'Metadatos editados';
$lang['media_perm_read']       = 'Disculpa, no tienes los permisos necesarios para leer ficheros.';
$lang['media_perm_upload']     = 'Disculpa, no tienes los permisos necesarios para cargar ficheros.';
$lang['media_update']          = 'Actualizar nueva versión';
$lang['media_restore']         = 'Restaurar esta versión';
